pub struct CT_PlotArea { /* private fields */ }Expand description
A plot-area shell. F-119 through F-122 replace selected raw slots with types.
Implementations
Sourceimpl CT_PlotArea
impl CT_PlotArea
pub fn raw_children(&self) -> &OrderedRawChildren
Sourcepub fn new(plots: Vec<Plot>, axes: Vec<Axis>) -> Result<Self>
pub fn new(plots: Vec<Plot>, axes: Vec<Axis>) -> Result<Self>
Creates a supported single-family plot area with owned axes.
Sourcepub fn plots(&self) -> Result<&[Plot]>
pub fn plots(&self) -> Result<&[Plot]>
Returns the owned supported plots, or an error for an opaque choice.
Sourcepub fn plots_mut(&mut self) -> Result<&mut [Plot]>
pub fn plots_mut(&mut self) -> Result<&mut [Plot]>
Returns mutable supported plots without exposing opaque content to edits.